"divchain"(x, ...)deldir() must have been called with a factor
valued z argument or the x argument to deldir()
must have had an appropriate component which could be taken to
be z.
rw (see deldir())
enclosing the points being tessellated. In these circumstances the
corresponding endpoint of the tile edge is the intersection of the
line joining the two circumcentres with the boundary of rw,
and the numeric value of the entry of column vi3 indicates
which side. The numbering follows the convention for numbering
the sides of a plot region in R: 1 for the bottom side,
2 for the left side, 3 for the top side and 4 for the right side.Note that the triple of vertices uniquely identify the endpoint
of the tile edge.The object has an attribute rw which is equal to the
specification of the rectangular window within which the
class deldir object x was constructed.
(See deldir().)
divchain.default() deldir()
plot.divchain()
set.seed(42)
x <- runif(50)
y <- runif(50)
z <- factor(kmeans(cbind(x,y),centers=4)$cluster)
dxy <- deldir(x,y,z=z,rw=c(0,1,0,1))
dc <- divchain(dxy)
Run the code above in your browser using DataLab